lino\_prima.lib.prima.user\_types
=================================

.. automodule:: lino_prima.lib.prima.user_types

   
   .. rubric:: Classes

   .. autosummary::
   
      Pupil
      SiteAdmin
      SiteStaff
      Teacher
   